"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs_1 = require("fs");
const ramljsonexpander = require("raml-jsonschema-expander");
const path_1 = require("path");
const parser_1 = require("../utils/parser");
const to_markdown_1 = require("../utils/to-markdown");
class Render extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Render);
        let ramlOBJ = await parser_1.default(args.file);
        ramlOBJ = ramljsonexpander.expandJsonSchemas(ramlOBJ);
        ramlOBJ.resources.forEach(async (resources) => {
            const title = resources.relativeUri.substring(1).replaceAll('/', '_').replaceAll('{', '').replaceAll('}', '');
            const ret = await to_markdown_1.default(title, ramlOBJ.baseUri, resources);
            try {
                let path = path_1.join(flags.out, title + '.md');
                if (flags['respect-version'] && ramlOBJ.version) {
                    path = path_1.join(flags.out, ramlOBJ.version, title + '.md');
                }
                // eslint-disable-next-line no-console
                console.log(`rendering ${path}`);
                await fs_1.promises.mkdir(path_1.dirname(path), { recursive: true });
                await fs_1.promises.writeFile(path, ret, { flag: 'w' });
            }
            catch (error) {
                // eslint-disable-next-line no-console
                console.log(error);
            }
        });
    }
}
exports.default = Render;
Render.description = 'render to markdown files';
Render.args = [
    {
        name: 'file',
        required: true,
    },
];
Render.flags = {
    help: command_1.flags.help({ char: 'h' }),
    out: command_1.flags.string({
        char: 'o',
        description: 'path to save the files',
        default: '.',
    }),
    'respect-version': command_1.flags.boolean({
        description: 'save the file to a /{version} path',
        default: false,
    }),
};
